@@ -23,7 +23,6 @@ use crate::types::{
 use crate::version;
 use envmnt;
 use fsio::path::as_path::AsPath;
-use fsio::path::canonicalize_or;
 use fsio::path::from_path::FromPath;
 use indexmap::IndexMap;
 use std::env;
@@ -359,7 +358,7 @@ fn load_external_descriptor(
 
     if file_path.exists() && file_path.is_file() {
         let file_path_string: String = FromPath::from_path(&file_path);
-        let absolute_file_path = canonicalize_or(&file_path, &file_path_string);
+        let absolute_file_path = io::canonicalize_to_string(&file_path_string);
 
         if set_env {
             envmnt::set("CARGO_MAKE_MAKEFILE_PATH", &absolute_file_path);
