@@ -1010,7 +1010,7 @@ pub struct Task {
     /// A list of tasks to execute before this task
     pub dependencies: Option<Vec<DependencyIdentifier>>,
     /// The rust toolchain used to invoke the command or install the needed crates/components
-    pub toolchain: Option<String>,
+    pub toolchain: Option<ToolchainSpecifier>,
     /// override task if runtime OS is Linux (takes precedence over alias)
     pub linux: Option<PlatformOverrideTask>,
     /// override task if runtime OS is Windows (takes precedence over alias)
@@ -1019,6 +1019,73 @@ pub struct Task {
     pub mac: Option<PlatformOverrideTask>,
 }
 
+/// A toolchain, defined either as a string (following the rustup syntax)
+/// or a ToolchainBoundedSpecifier.
+#[derive(Clone, Debug, Serialize, Deserialize, Eq, PartialEq)]
+#[serde(untagged)]
+pub enum ToolchainSpecifier {
+    /// A string specifying the channel name of the toolchain
+    Simple(String),
+    /// A toolchain with a minimum version bound
+    Bounded(ToolchainBoundedSpecifier),
+}
+
+impl From<String> for ToolchainSpecifier {
+    fn from(channel: String) -> Self {
+        Self::Simple(channel)
+    }
+}
+
+impl From<&str> for ToolchainSpecifier {
+    fn from(channel: &str) -> Self {
+        channel.to_string().into()
+    }
+}
+
+impl std::fmt::Display for ToolchainSpecifier {
+    fn fmt(&self, formatter: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match self {
+            Self::Simple(ref channel) => write!(formatter, "{}", channel),
+            Self::Bounded(ref spec) => write!(formatter, "{}", spec),
+        }
+    }
+}
+
+impl ToolchainSpecifier {
+    /// Return the channel of the toolchain to look for
+    pub fn channel(&self) -> &str {
+        match self {
+            Self::Simple(ref channel) => &channel,
+            Self::Bounded(ToolchainBoundedSpecifier { ref channel, .. }) => channel,
+        }
+    }
+
+    /// Return the minimal version, if any, to look for
+    pub fn min_version(&self) -> Option<&str> {
+        match self {
+            Self::Simple(_) => None,
+            Self::Bounded(ToolchainBoundedSpecifier {
+                ref min_version, ..
+            }) => Some(min_version),
+        }
+    }
+}
+
+/// A toolchain with a minumum version bound
+#[derive(Clone, Debug, Serialize, Deserialize, Eq, PartialEq)]
+pub struct ToolchainBoundedSpecifier {
+    /// The channel of the toolchain to use
+    pub channel: String,
+    /// The minimum version to match
+    pub min_version: String,
+}
+
+impl std::fmt::Display for ToolchainBoundedSpecifier {
+    fn fmt(&self, formatter: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(formatter, "{} >= {}", self.channel, self.min_version)
+    }
+}
+
 /// A dependency, defined either as a string or as a Dependency object
 #[derive(Clone, Debug, Serialize, Deserialize, Eq, PartialEq)]
 #[serde(untagged)]
@@ -1686,7 +1753,7 @@ pub struct PlatformOverrideTask {
     /// A list of tasks to execute before this task
     pub dependencies: Option<Vec<DependencyIdentifier>>,
     /// The rust toolchain used to invoke the command or install the needed crates/components
-    pub toolchain: Option<String>,
+    pub toolchain: Option<ToolchainSpecifier>,
 }
 
 impl PlatformOverrideTask {
